@@ -1,3 +1,4 @@
+from logging import Handler
 from typing import Any, Dict, Optional, Tuple
 
 import attr
@@ -14,7 +15,7 @@ class AuthConfig:
     token: Optional[str] = attr.ib(kw_only=True, default=None)
 
 
-@attr.s(slots=True)
+@attr.s(slots=True, kw_only=True)
 class PlanConfig:
     """Test plan configuration."""
 
@@ -32,5 +33,8 @@ class PlanConfig:
     # Current config version
     version = CONFIG_VERSION
 
+    test_case_log_handler: Optional[Handler] = attr.ib(kw_only=True, default=None)
+    runner_log_handler: Optional[Handler] = attr.ib(kw_only=True, default=None)
+
     # Shortcut to convert PlanConfig to dictionary
     asdict = attr.asdict
