@@ -14,13 +14,16 @@ import curlify
 import requests
 
 from .cwe import CWE
-from .events import Payload
 from .failures import Evidence
 from .status import Status
 from .types import Headers
 from .utils import format_exception
 
 
+class Payload:
+    """Base class for module-specific payload."""
+
+
 @attr.s(slots=True, repr=False)
 class Case:
     text_lines: Optional[List[str]] = attr.ib(default=None)
@@ -311,6 +314,13 @@ class SerializedError:
         )
 
 
+@attr.s(slots=True)
+class ValidationError:
+    message: str = attr.ib()
+    file: Optional[str] = attr.ib(default=None)
+    lines: Optional[list[str]] = attr.ib(default=None)
+
+
 @attr.s(slots=True)
 class SerializedCWE:
     code: int = attr.ib()
