@@ -3,7 +3,7 @@ from __future__ import annotations
 from enum import Enum
 
 
-class Status(Enum):
+class Status(str, Enum):
     """Resulting status of some action."""
 
     success = "success"
@@ -13,8 +13,8 @@ class Status(Enum):
     def __str__(self) -> str:
         return self.value
 
-    def __add__(self, other: Status) -> Status:
-        """Failure > Error > Success."""
+    def __add__(self, other: str) -> str:
+        """Error > Failure > Success."""
         if self == Status.error or other == Status.error:
             return Status.error
 
