@@ -25,4 +25,6 @@ def test_config():
             "token": None,
         },
         "module_specific_config": {},
+        "runner_log_handler": None,
+        "test_case_log_handler": None,
     }
